@@ -6,17 +6,13 @@ from __future__ import unicode_literals, print_function, division
 
 import base64
 import re
-import six
 import sys
 import textwrap
 
 from collections import OrderedDict
 from lxml.etree import _Comment, _ProcessingInstruction
 
-if six.PY2:
-    from urllib import quote
-else:
-    from urllib.request import quote
+from urllib.request import quote
 
 try:
     from xml2rfc import debug
@@ -64,7 +60,7 @@ class TextWrapper(textwrap.TextWrapper):
             # Tla with leading uppercase, and special cases
             # (Note: v1 spelled out Fig, Tbl, Mrs, Drs, Rep, Sen, Gov, Rev, Gen, Col, Maj and Cap,
             #  but those are redundant with the Tla regex.)
-            r'|([A-Z][a-z][a-z]|Eq|[Cc]f|vs|resp|viz|ibid|[JS]r|M[rs]|Messrs|Mmes|Dr|Profs?|St|Lt|i\.e)\.'
+            r'|([\(\[])?([A-Z][a-z][a-z]|Eq|[Cc]f|vs|resp|viz|ibid|[JS]r|M[rs]|Messrs|Mmes|Dr|Profs?|St|Lt|a\.k\.a|i\.e|e\.g)\.'
             r')\Z' # trailing dot, end of group and end of chunk
             )
 
@@ -268,9 +264,9 @@ def urlkeep(text, max=72):
                         .replace(':', ':' + wj_char)
                     )
     if 'http://' in text:
-        text = re.sub('http:\S*', replacer, text)
+        text = re.sub(r'http:\S*', replacer, text)
     if 'https://' in text:
-        text = re.sub('https:\S*', replacer, text)
+        text = re.sub(r'https:\S*', replacer, text)
     return text
 
 # ----------------------------------------------------------------------
@@ -286,13 +282,13 @@ def formatXmlWhitespace(tree):
         # Preserve formatting on artwork
         if element.tag != 'artwork':
             if element.text is not None:
-                element.text = re.sub('\s*\n\s*', ' ', \
-                               re.sub('\.\s*\n\s*', '.  ', \
+                element.text = re.sub(r'\s*\n\s*', ' ', \
+                               re.sub(r'\.\s*\n\s*', '.  ', \
                                element.text.lstrip()))
 
             if element.tail is not None:
-                element.tail = re.sub('\s*\n\s*', ' ', \
-                               re.sub('\.\s*\n\s*', '.  ', \
+                element.tail = re.sub(r'\s*\n\s*', ' ', \
+                               re.sub(r'\.\s*\n\s*', '.  ', \
                                element.tail))
 
 
@@ -580,7 +576,7 @@ def _replace_slashed_words(str, slashList):
     """ replace slashed separated words the list with
         <word1> &nbsp; / &nbsp; <word 2>
     """
-    match = re.findall(u'(\w+(/\w+)+)', str)
+    match = re.findall(r'(\w+(/\w+)+)', str)
     for item in match:
         if item[0] in slashList:
             str = re.sub(item[0], slashList[item[0]], str)
